/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.vorgang.grpc;

import java.util.List;
import java.util.stream.Stream;

import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.apilib.file.grpc.OzgCloudFileMapper;
import de.ozgcloud.apilib.vorgang.OzgCloudEingang;
import de.ozgcloud.apilib.vorgang.OzgCloudFormDataEntry;
import de.ozgcloud.apilib.vorgang.OzgCloudFormField;
import de.ozgcloud.apilib.vorgang.OzgCloudSubForm;
import de.ozgcloud.vorgang.vorgang.GrpcEingang;
import de.ozgcloud.vorgang.vorgang.GrpcFormData;
import de.ozgcloud.vorgang.vorgang.GrpcFormField;
import de.ozgcloud.vorgang.vorgang.GrpcSubForm;

@Mapper(uses = { OzgCloudFileGroupMapper.class, OzgCloudFileMapper.class },
	collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED,
	unmappedTargetPolicy = ReportingPolicy.WARN,
	nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS
)
public interface OzgCloudEingangMapper {

	@Mapping(target = "representation", ignore = true)
	@Mapping(target = "attachment", ignore = true)
	@Mapping(target = "formDataEntrys", source = "formData")
	@Mapping(target = "zustaendigeStelle.organisationsEinheitId", source = "zustaendigeStelle.organisationseinheitenId")
	@Mapping(target = "attachments", source = "attachmentsList")
	@Mapping(target = "representations", source = "representationsList")
	OzgCloudEingang fromGrpc(GrpcEingang eingang);

	default List<OzgCloudFormDataEntry> mapFormData(GrpcFormData value) {
		var fields = value.getFieldList().stream().map(this::fromGrpc);
		var subForms = value.getFormList().stream().map(this::fromGrpc);

		return Stream.concat(fields, subForms).toList();
	}

	OzgCloudFormField fromGrpc(GrpcFormField field);

	@Mapping(target = "formEntry", ignore = true)
	@Mapping(target = "formEntrys", source = "subForm")
	@Mapping(target = "name", source = "title")
	OzgCloudSubForm fromGrpc(GrpcSubForm subForm);

	default List<OzgCloudFormDataEntry> mapSubForm(GrpcSubForm subForm) {
		var fields = subForm.getFieldList().stream().map(this::fromGrpc);
		var subForms = subForm.getSubFormList().stream().map(this::fromGrpc);

		return Stream.concat(fields, subForms).toList();
	}

}
