/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.vorgang.grpc;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValuePropertyMappingStrategy;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.apilib.vorgang.OzgCloudServiceKonto;
import de.ozgcloud.apilib.vorgang.OzgCloudUserIdMapper;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgang;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangIdMapper;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangStatusMapper;
import de.ozgcloud.vorgang.vorgang.GrpcVorgangWithEingang;

@Mapper(uses = { OzgCloudEingangMapper.class, OzgCloudVorgangIdMapper.class, OzgCloudUserIdMapper.class, OzgCloudVorgangStatusMapper.class }, //
	nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE,
	nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface OzgCloudVorgangMapper {

	@Mapping(target = "eingangs", ignore = true)
	@Mapping(target = "vorgangNummer", source = "nummer")
	@Mapping(target = "vorgangName", source = "name")
	@Mapping(target = "header.aktenzeichen", source = "aktenzeichen")
	@Mapping(target = "header.assignedTo", source = "assignedTo")
	@Mapping(target = "header.createdAt", source = "createdAt")
	@Mapping(target = "header.status", source = "status")
	@Mapping(target = "header.serviceKonto", expression = "java(getServiceKonto(grpcVorgangWithEingang))")
	OzgCloudVorgang fromGrpc(GrpcVorgangWithEingang grpcVorgang);

	default OzgCloudServiceKonto getServiceKonto(GrpcVorgangWithEingang grpcVorgang) {
		var mapper = Mappers.getMapper(OzgCloudServiceKontoMapper.class);
		return mapper.getServiceKonto(grpcVorgang.getHeader());
	}
}
