/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.apilib.client_attribute.grpc;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.apilib.client_attribute.GrpcClientAttributeTestFactory;
import de.ozgcloud.apilib.client_attribute.OzgCloudClientAttributeTestFactory;

class OzgCloudClientAttributeMapperTest {

	private OzgCloudClientAttributeMapper mapper = Mappers.getMapper(OzgCloudClientAttributeMapper.class);

	@Test
	void shouldMapBooleanAttribute() {
		var result = mapper.toGrpc(OzgCloudClientAttributeTestFactory.createBoolean());

		assertThat(result).usingRecursiveComparison().isEqualTo(GrpcClientAttributeTestFactory.createBoolean());
	}

	@Test
	void shouldMapStringAttribute() {
		var result = mapper.toGrpc(OzgCloudClientAttributeTestFactory.createString());

		assertThat(result).usingRecursiveComparison().isEqualTo(GrpcClientAttributeTestFactory.createString());
	}

	@Test
	void shouldMapLongAttribute() {
		var result = mapper.toGrpc(OzgCloudClientAttributeTestFactory.createLong());

		assertThat(result).usingRecursiveComparison().isEqualTo(GrpcClientAttributeTestFactory.createLong());
	}

	@Test
	void shouldMapDoubleAttribute() {
		var result = mapper.toGrpc(OzgCloudClientAttributeTestFactory.createDouble());

		assertThat(result).usingRecursiveComparison().isEqualTo(GrpcClientAttributeTestFactory.createDouble());
	}
}