/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.vorgang.grpc;

import static de.ozgcloud.apilib.vorgang.OzgCloudAntragstellerTestFactory.*;

import de.ozgcloud.vorgang.vorgang.GrpcAntragsteller;
import de.ozgcloud.vorgang.vorgang.GrpcFormData;
import de.ozgcloud.vorgang.vorgang.GrpcFormField;
import de.ozgcloud.vorgang.vorgang.GrpcSubForm;

public class GrpcAntragstellerTestFactory {

	public static GrpcAntragsteller create() {
		return createBuilder().build();
	}

	public static GrpcAntragsteller.Builder createBuilder() {
		return GrpcAntragsteller.newBuilder()
				.setAnrede(ANREDE)
				.setVorname(FIRSTNAME)
				.setNachname(NACHNAME)
				.setFirmaName(FIRMA_NAME)
				.setGeburtsdatum(GEBURTSDATUM)
				.setGeburtsort(GEBURTSORT)
				.setGeburtsname(GEBURTSNAME)
				.setStrasse(STRASSE)
				.setHausnummer(HAUSNUMMER)
				.setPlz(PLZ)
				.setOrt(ORT)
				.setEmail(E_MAIL)
				.setTelefon(TELEFON)
				.setOtherData(createOtherData());
	}

	public static GrpcFormData createOtherData() {
		return GrpcFormData.newBuilder()
			.addField(GrpcFormField.newBuilder().setName(FIELD_NAME).setLabel(FIELD_LABEL).setValue(FIELD_VALUE))
			.addForm(GrpcSubForm.newBuilder().setTitle(SUB_FORM_NAME).setLabel(SUB_FORM_LABEL)
				.addField(GrpcFormField.newBuilder().setName(SUB_FORM_FIELD_NAME).setLabel(SUB_FORM_FIELD_LABEL).setValue(SUB_FORM_FIELD_VALUE)))
			.build();
	}
}
